@@ -305,41 +305,41 @@ BP[BP == "NORMAL:HIGH"] = sample(LV3, length(which(BP == "NORMAL:HIGH")), prob =
 BP[BP == "HIGH:HIGH"] = sample(LV3, length(which(BP == "HIGH:HIGH")), prob = c(0.01, 0.09, 0.90), replace = TRUE)
 
 alarm = data.frame(
-  CVP  = CVP,
-  PCWP = PCWP,
-  HIST = HISTORY,
-  TPR  = TPR,
-  BP   = BP,
-  CO   = CO,
-  HRBP = HRBP,
-  HREK = HREKG,
-  HRSA = HRSAT,
-  PAP  = PAP,
-  SAO2 = SAO2,
-  FIO2 = FIO2,
-  PRSS = PRESS,
-  ECO2 = EXPCO2,
-  MINV = MINVOL,
-  MVS  = MINVOLSET,
-  HYP  = HYPOVOLEMIA,
-  LVF  = LVFAILURE,
-  APL  = ANAPHYLAXIS,
-  ANES = INSUFFANESTH,
-  PMB  = PULMEMBOLUS,
-  INT  = INTUBATION,
-  KINK = KINKEDTUBE,
-  DISC = DISCONNECT,
-  LVV  = LVEDVOLUME,
-  STKV = STROKEVOLUME,
-  CCHL = CATECHOL,
-  ERLO = ERRLOWOUTPUT,
-  HR   = HR,
-  ERCA = ERRCAUTER,
-  SHNT = SHUNT,
-  PVS  = PVSAT,
-  ACO2 = ARTCO2,
-  VALV = VENTALV,
-  VLNG = VENTLUNG,
-  VTUB = VENTTUBE,
-  VMCH = VENTMACH
+  CVP  = factor(CVP, levels = LV3),
+  PCWP = factor(PCWP, levels = LV3),
+  HIST = factor(HISTORY, levels = BOOL),
+  TPR  = factor(TPR, levels = LV3),
+  BP   = factor(BP, levels = LV3),
+  CO   = factor(CO, levels = LV3),
+  HRBP = factor(HRBP, levels = LV3),
+  HREK = factor(HREKG, levels = LV3),
+  HRSA = factor(HRSAT, levels = LV3),
+  PAP  = factor(PAP, levels = LV3),
+  SAO2 = factor(SAO2, levels = LV3),
+  FIO2 = factor(FIO2, levels = c("LOW", "NORMAL")),
+  PRSS = factor(PRESS, levels = LV4),
+  ECO2 = factor(EXPCO2, levels = LV4),
+  MINV = factor(MINVOL, levels = LV4),
+  MVS  = factor(MINVOLSET, levels = LV3),
+  HYP  = factor(HYPOVOLEMIA, levels = BOOL),
+  LVF  = factor(LVFAILURE, levels = BOOL),
+  APL  = factor(ANAPHYLAXIS, levels = BOOL),
+  ANES = factor(INSUFFANESTH, levels = BOOL),
+  PMB  = factor(PULMEMBOLUS, levels = BOOL),
+  INT  = factor(INTUBATION, levels = c("NORMAL", "ESOPHAGEAL", "ONESIDED")),
+  KINK = factor(KINKEDTUBE, levels = BOOL),
+  DISC = factor(DISCONNECT, levels = BOOL),
+  LVV  = factor(LVEDVOLUME, levels = LV3),
+  STKV = factor(STROKEVOLUME, levels = LV3),
+  CCHL = factor(CATECHOL, levels = LV2),
+  ERLO = factor(ERRLOWOUTPUT, levels = BOOL),
+  HR   = factor(HR, levels = LV3),
+  ERCA = factor(ERRCAUTER, levels = BOOL),
+  SHNT = factor(SHUNT, levels = c("NORMAL", "HIGH")),
+  PVS  = factor(PVSAT, levels = LV3),
+  ACO2 = factor(ARTCO2, levels = LV3),
+  VALV = factor(VENTALV, levels = LV4),
+  VLNG = factor(VENTLUNG, levels = LV4),
+  VTUB = factor(VENTTUBE, levels = LV4),
+  VMCH = factor(VENTMACH, levels = LV4)
 )
